


import sys
import time
import os
from typing import List

from mitoinstaller.installer_steps.installer_step import InstallerStep


def get_installer_start_message() -> str:

    # First, build the checklist of the completed steps

    is_install = 'install' in sys.argv

    if is_install:
        return 'Starting Mito install. This make take a few moments.\n\nIn the meantime, check out a 2 minute intro to Mito: https://www.youtube.com/watch?v=LFfWfqzdKyE\n'
    else: 
        return 'Starting Mito upgrade. This make take a few moments.\n\nIn the meantime, check out our docs: https://docs.trymito.io\n'


import json

from mitoinstaller.user_install import (USER_JSON_PATH, get_static_user_id,
                                        user_json_is_installer_default)

from tests.conftest import VirtualEnvironment


def test_upgrade_with_mitosheet3_moves_to_mitosheet(venv: VirtualEnvironment):
    # Setup what most of our old users used to have
    venv.run_python_module_command(['pip', 'install', '-r', 'requirements.txt'])
    venv.run_python_module_command(['pip', 'install', 'mitosheet3'])
    assert venv.get_package_version('mitosheet3') is not None

    venv.run_python_module_command(['mitoinstaller', 'install', '--test-pypi'])

    assert venv.get_package_version('mitosheet3') is None 
    assert venv.get_package_version('mitosheet') is not None 
    assert venv.get_package_version('jupyterlab').startswith('3')


def test_upgrade_mitosheet_installed_correctly_upgrades_stays_3(venv: VirtualEnvironment):
    venv.run_python_module_command(['pip', 'install', '-r', 'requirements.txt'])
    venv.run_python_module_command(['mitoinstaller', 'install', '--test-pypi'])
    static_user_id_one = get_static_user_id()

    venv.run_python_module_command(['mitoinstaller', 'upgrade', '--test-pypi'])
    static_user_id_two = get_static_user_id()

    assert static_user_id_one == static_user_id_two
    
    mitosheet_version = venv.get_package_version('mitosheet')
    jlab_version = venv.get_package_version('jupyterlab')

    assert mitosheet_version is not None 
    assert jlab_version.startswith('3')


def test_user_json_only_has_static_user_id():
    with open(USER_JSON_PATH, 'w+') as f:
        f.write(json.dumps({
            'static_user_id': 'github_action'
        }))
    
    assert user_json_is_installer_default()

    with open(USER_JSON_PATH, 'w+') as f:
        f.write(json.dumps({
            'static_user_id': 'github_action',
            'other': 'nah',
            'other1': 'nah',
            'other2': 'nah',
            'other3': 'nah',
            'other4': 'nah',
            'other5': 'nah',
        }))

    assert not user_json_is_installer_default()



import random
from typing import Dict, Optional


def get_random_variant() -> str:
    """Returns "A" or "B" with 50% probability
    
    Currently, as we have no experiment, only returns B"""
    return "B"

def get_new_experiment() -> Dict[str, str]:
    # NOTE: this needs to match the mitosheet package!
    return {
        'experiment_id': 'installer_communication_and_time_to_value',
        'variant': get_random_variant(),
    }

def is_variant_a() -> bool:
    from mitoinstaller.user_install import get_current_experiment
    current_experiment = get_current_experiment()
    return current_experiment is None or current_experiment['variant'] == 'A'

def is_variant_b() -> bool:
    return not is_variant_a()